



pip check
IF %ERRORLEVEL% NEQ 0 exit /B 1
python test_licenses.py --ignore oxigraph,oxigraph_js,oxigraph_server,oxigraph_testsuite,oxigraph_wikibase,pyoxigraph
IF %ERRORLEVEL% NEQ 0 exit /B 1
cd python/tests
IF %ERRORLEVEL% NEQ 0 exit /B 1
pytest -vv --cov pyoxigraph --cov-report term-missing:skip-covered --cov-fail-under 100
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
